Welcome to ClientVPS Mirrors

Help for package oews2021
Type: Package
Title: May 2021 Occupational Employment and Wage Statistics
Version: 1.0.0
Author: Christopher Mann
Maintainer: Christopher Mann <cmann3@unl.edu>
Description: Contains data from the May 2021 Occupational Employment and Wage Statistics data release from the U.S. Bureau of Labor Statistics. The dataset covers employment and wages across occupations, industries, states, and at the national level. Metropolitan data is not included.
License: MIT + file LICENSE
Depends: R (≥ 3.5.0)
Encoding: UTF-8
LazyData: true
LazyDataCompression: bzip2
RoxygenNote: 7.2.1
NeedsCompilation: no
Packaged: 2022-09-21 14:20:10 UTC; chris
Repository: CRAN
Date/Publication: 2022-09-21 16:20:02 UTC

Occupational Employment and Wage Statistics, May 2021

Description

U.S. Bureau of Labor Statistics data on wages and employment across occupations at the national, state, and industry levels. This dataset does not include data at the metropolitan level. NA values are used when data is unavailable, the percentage of establishments reporting is less than 0.5

Usage

data(oews2021)

Format

A data frame with 211,275 rows and 26 variables

Details

Bureau of Labor Statistics, U.S. Department of Labor, Occupational Employment and Wage Statistics

References

Bureau of Labor Statistics, U.S. Department of Labor, Occupational Employment and Wage Statistics, 2022-09-19. https://www.bls.gov/oes/tables.htm

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.